@@ -206,7 +206,47 @@ GType  bd_fs_vfat_info_get_type () {
     return type;
 }
 
-static const gchar const * const fs_functions[] = {
+/**
+ * BDFSNtfsInfo:
+ * @size: size of the filesystem in bytes
+ * @free_space: number of free space in the filesystem in bytes
+ */
+/**
+ * bd_fs_ntfs_info_copy: (skip)
+ *
+ * Creates a new copy of @data.
+ */
+BDFSNtfsInfo* bd_fs_ntfs_info_copy (BDFSNtfsInfo *data) {
+        BDFSNtfsInfo *ret = g_new0 (BDFSNtfsInfo, 1);
+
+    ret->size = data->size;
+    ret->free_space = data->free_space;
+
+    return ret;
+}
+
+/**
+ * bd_fs_ntfs_info_free: (skip)
+ *
+ * Frees @data.
+ */
+void  bd_fs_ntfs_info_free (BDFSNtfsInfo *data) {
+        g_free (data);
+}
+
+GType  bd_fs_ntfs_info_get_type () {
+        static GType type = 0;
+
+    if (G_UNLIKELY(type == 0)) {
+        type = g_boxed_type_register_static("BDFSNtfsInfo",
+                                            (GBoxedCopyFunc) bd_fs_ntfs_info_copy,
+                                            (GBoxedFreeFunc) bd_fs_ntfs_info_free);
+    }
+
+    return type;
+}
+
+static const gchar* const fs_functions[] = {
     "bd_fs_is_tech_avail",
     "bd_fs_wipe",
     "bd_fs_clean",
@@ -257,13 +297,20 @@ static const gchar const * const fs_functions[] = {
     "bd_fs_vfat_set_label",
     "bd_fs_vfat_get_info",
     "bd_fs_vfat_resize",
+    "bd_fs_ntfs_mkfs",
+    "bd_fs_ntfs_wipe",
+    "bd_fs_ntfs_check",
+    "bd_fs_ntfs_repair",
+    "bd_fs_ntfs_set_label",
+    "bd_fs_ntfs_resize",
+    "bd_fs_ntfs_get_info",
     NULL};
 
-gchar const * const * get_fs_functions (void) {
+const gchar* const* get_fs_functions (void) {
     return fs_functions;
 }
 
-static const guint8 fs_num_functions = 50;
+static const guint8 fs_num_functions = 57;
 
 guint8 get_fs_num_functions (void) {
     return fs_num_functions;
@@ -1571,6 +1618,177 @@ gboolean  bd_fs_vfat_resize (const gchar *device, guint64 new_size, GError **err
 }
 
 
+gboolean  bd_fs_ntfs_mkfs_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_mkfs' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_mkfs' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_mkfs) (const gchar *device, const BDExtraArg **extra, GError **error) = bd_fs_ntfs_mkfs_stub;
+
+/**
+ * bd_fs_ntfs_mkfs:
+ * @device: the device to create a new ntfs fs on
+ * @extra: (allow-none) (array zero-terminated=1): extra options for the creation (right now
+ *                                                 passed to the 'mkntfs' utility)
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether a new NTFS fs was successfully created on @device or not
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_MKFS
+ */
+gboolean  bd_fs_ntfs_mkfs (const gchar *device, const BDExtraArg **extra, GError **error) {
+    return _bd_fs_ntfs_mkfs (device, extra, error);
+}
+
+
+gboolean  bd_fs_ntfs_wipe_stub (const gchar *device, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_wipe' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_wipe' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_wipe) (const gchar *device, GError **error) = bd_fs_ntfs_wipe_stub;
+
+/**
+ * bd_fs_ntfs_wipe:
+ * @device: the device to wipe an ntfs signature from
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether an ntfs signature was successfully wiped from the @device or not
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_WIPE
+ */
+gboolean  bd_fs_ntfs_wipe (const gchar *device, GError **error) {
+    return _bd_fs_ntfs_wipe (device, error);
+}
+
+
+gboolean  bd_fs_ntfs_check_stub (const gchar *device, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_check' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_check' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_check) (const gchar *device, GError **error) = bd_fs_ntfs_check_stub;
+
+/**
+ * bd_fs_ntfs_check:
+ * @device: the device containing the file system to check
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether an ntfs file system on the @device is clean or not
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_CHECK
+ */
+gboolean  bd_fs_ntfs_check (const gchar *device, GError **error) {
+    return _bd_fs_ntfs_check (device, error);
+}
+
+
+gboolean  bd_fs_ntfs_repair_stub (const gchar *device, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_repair' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_repair' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_repair) (const gchar *device, GError **error) = bd_fs_ntfs_repair_stub;
+
+/**
+ * bd_fs_ntfs_repair:
+ * @device: the device containing the file system to repair
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether an NTFS file system on the @device was successfully repaired
+ *          (if needed) or not (error is set in that case)
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_REPAIR
+ */
+gboolean  bd_fs_ntfs_repair (const gchar *device, GError **error) {
+    return _bd_fs_ntfs_repair (device, error);
+}
+
+
+gboolean  bd_fs_ntfs_set_label_stub (const gchar *device, const gchar *label, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_set_label' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_set_label' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_set_label) (const gchar *device, const gchar *label, GError **error) = bd_fs_ntfs_set_label_stub;
+
+/**
+ * bd_fs_ntfs_set_label:
+ * @device: the device containing the file system to set the label for
+ * @label: label to set
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether the label of the NTFS file system on the @device was
+ *          successfully set or not
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_SET_LABEL
+ */
+gboolean  bd_fs_ntfs_set_label (const gchar *device, const gchar *label, GError **error) {
+    return _bd_fs_ntfs_set_label (device, label, error);
+}
+
+
+gboolean  bd_fs_ntfs_resize_stub (const gchar *device, guint64 new_size, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_resize' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_resize' called, but not implemented!");
+    return FALSE;
+}
+
+gboolean  (*_bd_fs_ntfs_resize) (const gchar *device, guint64 new_size, GError **error) = bd_fs_ntfs_resize_stub;
+
+/**
+ * bd_fs_ntfs_resize:
+ * @device: the device the file system of which to resize
+ * @new_size: new requested size for the file system in bytes (if 0, the file system
+ *            is adapted to the underlying block device)
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether the file system on @device was successfully resized or not
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_RESIZE
+ */
+gboolean  bd_fs_ntfs_resize (const gchar *device, guint64 new_size, GError **error) {
+    return _bd_fs_ntfs_resize (device, new_size, error);
+}
+
+
+BDFSNtfsInfo* bd_fs_ntfs_get_info_stub (const gchar *device, GError **error) {
+    g_critical ("The function 'bd_fs_ntfs_get_info' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_fs_ntfs_get_info' called, but not implemented!");
+    return NULL;
+}
+
+BDFSNtfsInfo* (*_bd_fs_ntfs_get_info) (const gchar *device, GError **error) = bd_fs_ntfs_get_info_stub;
+
+/**
+ * bd_fs_ntfs_get_info:
+ * @device: the device containing the file system to get info for (device must
+            not be mounted, trying to get info for a mounted device will result
+            in an error)
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: (transfer full): information about the file system on @device or
+ *                           %NULL in case of error
+ *
+ * Tech category: %BD_FS_TECH_NTFS-%BD_FS_TECH_MODE_QUERY
+ */
+BDFSNtfsInfo* bd_fs_ntfs_get_info (const gchar *device, GError **error) {
+    return _bd_fs_ntfs_get_info (device, error);
+}
+
+
 gpointer load_fs_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
@@ -1851,6 +2069,41 @@ gpointer load_fs_from_plugin(const gchar *so_name) {
     if ((error = dlerror()) != NULL)
         g_warning("failed to load bd_fs_vfat_resize: %s", error);
 
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_mkfs) = dlsym(handle, "bd_fs_ntfs_mkfs");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_mkfs: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_wipe) = dlsym(handle, "bd_fs_ntfs_wipe");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_wipe: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_check) = dlsym(handle, "bd_fs_ntfs_check");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_check: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_repair) = dlsym(handle, "bd_fs_ntfs_repair");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_repair: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_set_label) = dlsym(handle, "bd_fs_ntfs_set_label");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_set_label: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_resize) = dlsym(handle, "bd_fs_ntfs_resize");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_resize: %s", error);
+
+    dlerror();
+    * (void**) (&_bd_fs_ntfs_get_info) = dlsym(handle, "bd_fs_ntfs_get_info");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_fs_ntfs_get_info: %s", error);
+
     return handle;
 }
 
@@ -1908,6 +2161,13 @@ gboolean unload_fs (gpointer handle) {
     _bd_fs_vfat_set_label = bd_fs_vfat_set_label_stub;
     _bd_fs_vfat_get_info = bd_fs_vfat_get_info_stub;
     _bd_fs_vfat_resize = bd_fs_vfat_resize_stub;
+    _bd_fs_ntfs_mkfs = bd_fs_ntfs_mkfs_stub;
+    _bd_fs_ntfs_wipe = bd_fs_ntfs_wipe_stub;
+    _bd_fs_ntfs_check = bd_fs_ntfs_check_stub;
+    _bd_fs_ntfs_repair = bd_fs_ntfs_repair_stub;
+    _bd_fs_ntfs_set_label = bd_fs_ntfs_set_label_stub;
+    _bd_fs_ntfs_resize = bd_fs_ntfs_resize_stub;
+    _bd_fs_ntfs_get_info = bd_fs_ntfs_get_info_stub;
 
     dlerror();
     * (void**) (&close_fn) = dlsym(handle, "bd_fs_close");
