@@ -81,7 +81,7 @@ GType  bd_part_disk_spec_get_type () {
     return type;
 }
 
-static const gchar const * const part_functions[] = {
+static const gchar* const part_functions[] = {
     "bd_part_is_tech_avail",
     "bd_part_create_table",
     "bd_part_get_part_spec",
@@ -105,7 +105,7 @@ static const gchar const * const part_functions[] = {
     "bd_part_get_type_str",
     NULL};
 
-gchar const * const * get_part_functions (void) {
+const gchar* const* get_part_functions (void) {
     return part_functions;
 }
 
