@@ -2,7 +2,7 @@ GQuark  bd_s390_error_quark (void) {
         return g_quark_from_static_string ("g-bd-s390-error-quark");
 }
 
-static const gchar const * const s390_functions[] = {
+static const gchar* const s390_functions[] = {
     "bd_s390_is_tech_avail",
     "bd_s390_dasd_format",
     "bd_s390_dasd_needs_format",
@@ -17,7 +17,7 @@ static const gchar const * const s390_functions[] = {
     "bd_s390_zfcp_offline",
     NULL};
 
-gchar const * const * get_s390_functions (void) {
+const gchar* const* get_s390_functions (void) {
     return s390_functions;
 }
 
